==> haskell-shelly-1.8.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shelly
version: 1.8.1
id: shelly-1.8.1-3aodrmgc5IM4IpB3TntKv8
key: shelly-1.8.1-3aodrmgc5IM4IpB3TntKv8
license: BSD-3-Clause
maintainer: Greg Weber <greg@gregweber.info>
author: Greg Weber, Petr Rockai
homepage: https://github.com/yesodweb/Shelly.hs
synopsis: shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:
    .
    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance.
    .
    * has detailed and useful error messages
    .
    * maintains its own environment, making it thread-safe.
    .
    * is modern, using Text and system-filepath/system-fileio
    .
    Shelly is originally forked from the Shellish package.
    .
    See the shelly-extra package for additional functionality.
    .
    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>
category: Development
abi: 28cdc3ef08cc023335b662457f6d590f
exposed: True
exposed-modules:
    Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules: Shelly.Base Shelly.Find Shelly.Directory
import-dirs: /usr/lib/ghc-8.6.3/site-local/shelly-1.8.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/shelly-1.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/shelly-1.8.1
hs-libraries: HSshelly-1.8.1-3aodrmgc5IM4IpB3TntKv8
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    enclosed-exceptions-1.0.3-6nvnvk4MQ931ywXCzlGO3G
    exceptions-0.10.0-29UXSV5bKJ4B0H4dLl5Nff
    lifted-async-0.10.0.3-H7SU15DSgvq4mPIJ9WC1pf
    lifted-base-0.2.3.12-JTqF5FHkOGhHiR71SkwFRG
    monad-control-1.0.2.3-8mWjhu0S94p37ozPEL8Dki mtl-2.2.2
    process-1.6.3.0 system-fileio-0.3.16.4-HlRuLFEUs5510FaMgZTWEJ
    system-filepath-0.4.14-FRUtJu5zAWTG9MKrRBz8D6 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.5.0
    transformers-base-0.4.5.2-6sqJnZSEiKyFksWegWCsAG unix-2.7.2.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html: /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shelly-1.8.1-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shelly
version: 1.8.1
id: shelly-1.8.1-CFxpyUmxeOXCAYFOIPo1La
key: shelly-1.8.1-CFxpyUmxeOXCAYFOIPo1La
license: BSD-3-Clause
maintainer: Greg Weber <greg@gregweber.info>
author: Greg Weber, Petr Rockai
homepage: https://github.com/yesodweb/Shelly.hs
synopsis: shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:
    .
    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance.
    .
    * has detailed and useful error messages
    .
    * maintains its own environment, making it thread-safe.
    .
    * is modern, using Text and system-filepath/system-fileio
    .
    Shelly is originally forked from the Shellish package.
    .
    See the shelly-extra package for additional functionality.
    .
    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>
category: Development
abi: 95e306b8c01818d2db361b64544406d9
exposed: True
exposed-modules:
    Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules: Shelly.Base Shelly.Find Shelly.Directory
import-dirs: /usr/lib/ghc-8.6.4/site-local/shelly-1.8.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/shelly-1.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/shelly-1.8.1
hs-libraries: HSshelly-1.8.1-CFxpyUmxeOXCAYFOIPo1La
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    enclosed-exceptions-1.0.3-HXOTwSyhnoaJLBT2G4XWmc
    exceptions-0.10.0-HSEN1HsF9E42usfcjSNYsT
    lifted-async-0.10.0.3-2bqv0G08EAR2yffs36jy1I
    lifted-base-0.2.3.12-Klk21x2DK8zCkpPSbkVMeZ
    monad-control-1.0.2.3-8d9BFLxdv0m5ZddAp98CYo mtl-2.2.2
    process-1.6.5.0 system-fileio-0.3.16.4-HlRuLFEUs5510FaMgZTWEJ
    system-filepath-0.4.14-FRUtJu5zAWTG9MKrRBz8D6 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-CiZEid5DnKxKMvWGI9SJsd unix-2.7.2.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html: /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
